@@ -1,5 +1,5 @@
 # Version of the python-kacl package
-__version__ = "0.6.5"
+__version__ = "0.6.6"
 
 from kacl.document import KACLDocument
 from kacl.serializer import KACLMarkdownSerializer
@@ -14,14 +14,14 @@ def load(file):
     with open(file, "r") as f:
         document = f.read()
         try:
-            doc = KACLDocument.parse(document)
+            doc = KACLDocument.parse(document, file)
         finally:
             f.close()
     return doc
 
 
-def parse(text):
-    return KACLDocument.parse(text)
+def parse(text, file=None):
+    return KACLDocument.parse(text, file)
 
 
 def dump(document):
