@@ -11,6 +11,8 @@ class KACLChanges(KACLElement):
             line_number=element.line_number(),
         )
         self.__items = []
+        # initializes
+        self.items()
 
     def items(self):
         if not len(self.__items) and len(self.body().strip()):
