@@ -4,6 +4,7 @@ import os
 import git
 import semver
 
+import kacl
 from kacl.config import KACLConfig
 from kacl.element import KACLElement
 from kacl.exception import KACLException
@@ -28,6 +29,7 @@ class KACLDocument:
         versions=None,
         link_references=None,
         meta_data=None,
+        file_path=None,
         config=KACLConfig(),
     ):
         self.__data = data
@@ -38,6 +40,80 @@ class KACLDocument:
             self.__link_references = dict()
         self.__meta_data = meta_data
         self.config = config
+        self.stash = []
+        self.file_path = file_path
+
+    @property
+    def stash_directory(self):
+        return self._ensure_stash_directory()
+
+    def load_stash(self):
+        self._refresh_stash()
+        # get all unreleased changes from stash
+        for stashed_changelog in self.stash:
+            unreleased_stash_version = stashed_changelog.get("Unreleased")
+            for title, change in unreleased_stash_version.sections().items():
+                for change_item in change.items():
+                    self.add(section=title, data=change_item)
+
+    def _refresh_stash(self):
+        if not self.file_path:
+            return
+
+        self.stash = []
+        if self.file_path is None:
+            local_stash_dir = os.path.join(
+                os.path.abspath(os.getcwd()), self.config.stash_dir
+            )
+        else:
+            # the stash needs always to be relative to the current file_path
+            local_stash_dir = os.path.join(
+                os.path.abspath(os.path.dirname(self.file_path)), self.config.stash_dir
+            )
+
+        if not os.path.isdir(local_stash_dir):
+            return
+
+        # read all md files in the stash directory
+        for f in os.listdir(local_stash_dir):
+            if f.endswith(".md"):
+                md_file = os.path.join(local_stash_dir, f)
+                with open(md_file, "r") as fh:
+                    data = fh.read()
+                    try:
+                        doc = KACLDocument.parse(data, None)
+                        self.stash.append(doc)
+                    except Exception:
+                        continue
+
+    def _ensure_stash_directory(self):
+        # the stash needs always to be relative to the current file_path
+        local_stash_dir = os.path.join(
+            os.path.abspath(os.path.dirname(self.file_path)), self.config.stash_dir
+        )
+
+        if not os.path.isdir(local_stash_dir):
+            os.makedirs(local_stash_dir, exist_ok=True)
+
+        return local_stash_dir
+
+    def _get_stash_file(self):
+        # the stash file should be named after the current git branch
+        local_stash_dir = self._ensure_stash_directory()
+        try:
+            repo = git.Repo(
+                os.path.abspath(os.path.dirname(self.file_path)),
+                search_parent_directories=True,
+            )
+            branch_name = repo.active_branch.name
+            # sanitize branch name for filename
+            branch_name = branch_name.replace("/", "__").replace("\\", "_")
+            stash_file_name = f"{branch_name}.md"
+        except Exception:
+            # fallback to with date
+            stash_file_name = f"{datetime.datetime.now().strftime('%Y%m%d')}.md"
+
+        return os.path.join(local_stash_dir, stash_file_name)
 
     def validate(self):
         """Validates the current changelog and returns KACLValidation object containing all information
@@ -46,6 +122,14 @@ class KACLDocument:
             [KACLValidation] -- object holding all error information
         """
         validation = KACLValidation()
+
+        # first load the stash
+        self._refresh_stash()
+        for stashed_changelog in self.stash:
+            val = stashed_changelog.validate()
+            for e in val.errors():
+                validation.add(e)
+
         # 1. assert only one header and starts on first line
         if len(self.__headers) == 0:
             validation.add_error(
@@ -213,18 +297,38 @@ class KACLDocument:
 
         return False
 
-    def add(self, section, data):
+    def add(self, section, data, stash=False):
         """adds a new change to a given section in the 'unreleased' version
 
         Arguments:
             section {[str]} -- section to add data to
             data {[str]} -- change information
+            stash {[bool]} -- if true the change will be stashed instead of added to the changelog (default: {False})
         """
-        unreleased_version = self.get("Unreleased")
-        if unreleased_version is None:
-            unreleased_version = KACLVersion(version="Unreleased")
-            self.__versions.insert(0, unreleased_version)
-        unreleased_version.add(section.capitalize(), data)
+
+        if stash:
+            # check if the stash directory already contains the required changelog file, if not initialize it
+            stash_file = self._get_stash_file()
+
+            if not os.path.exists(stash_file):
+                kacl_changelog = kacl.new()
+                kacl_changelog_content = kacl.dump(kacl_changelog)
+                with open(stash_file, "w") as f:
+                    f.write(kacl_changelog_content)
+                f.close()
+
+            kacl_changelog = kacl.load(stash_file)
+            kacl_changelog.add(section.capitalize(), data)
+            kacl_changelog_content = kacl.dump(kacl_changelog)
+            with open(stash_file, "w") as f:
+                f.write(kacl_changelog_content)
+            f.close()
+        else:
+            unreleased_version = self.get("Unreleased")
+            if unreleased_version is None:
+                unreleased_version = KACLVersion(version="Unreleased")
+                self.__versions.insert(0, unreleased_version)
+            unreleased_version.add(section.capitalize(), data)
 
     def release(
         self,
@@ -584,7 +688,7 @@ The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
         )
 
     @staticmethod
-    def parse(data):
+    def parse(data, file=None):
         """Parses a given text object and returns the KACLDocument
 
         Arguments:
@@ -624,6 +728,7 @@ The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
             versions=versions,
             link_references=link_references,
             meta_data=meta_data,
+            file_path=file,
         )
 
     def __get_link_provider(
