@@ -69,6 +69,7 @@ def load_changelog(ctx):
     # read the changelog
     kacl_changelog = kacl.load(kacl_config.changelog_file_path)
     kacl_changelog.config = kacl_config
+    kacl_changelog.load_stash()
 
     # share the objects
     return kacl_changelog
@@ -128,14 +129,28 @@ def cli(ctx, version=None, config=None, file=None):
     is_flag=True,
     help="This option will add the changes directly into changelog file.",
 )
-def add(ctx, section, message, modify):
+@click.option(
+    "-s",
+    "--stash",
+    is_flag=True,
+    help="This option will stash changes instead of applying them.",
+)
+def add(ctx, section, message, modify, stash):
     """Adds a given message to a specified unreleased section. Use '--modify' to directly modify the changelog file."""
     kacl_changelog = load_changelog(ctx)
 
+    if not modify:
+        stash = False
+    else:
+        # check if we need to stash
+        stash = stash or kacl_changelog.config.stash_always
+
     # add changes to changelog
-    kacl_changelog.add(section=section, data=message)
+    kacl_changelog.add(section=section, data=message, stash=stash)
+
     kacl_changelog_content = kacl.dump(kacl_changelog)
-    if modify:
+    # if stashing is enabled, do not modify the changelog file
+    if modify and not stash:
         with open(kacl_changelog.config.changelog_file_path, "w") as f:
             f.write(kacl_changelog_content)
         f.close()
@@ -472,6 +487,13 @@ def release(
         if no_commit:
             return
 
+        # delete all file in the stash directory
+        stash_files = []
+        for f in os.listdir(kacl_changelog.stash_directory):
+            stash_file = os.path.join(kacl_changelog.stash_directory, f)
+            os.remove(stash_file)
+            stash_files.append(stash_file)
+
         if commit or tag or kacl_config.git_create_commit or kacl_config.git_create_tag:
             vcs_context = {
                 "latest_version": latest_version,
@@ -516,6 +538,11 @@ def release(
                     repo.git.add(kacl_config.changelog_file_path)
                     for f in kacl_config.git_commit_additional_files:
                         repo.git.add(f)
+                    for f in stash_files:
+                        try:
+                            repo.git.add(f)
+                        except git.GitCommandError:
+                            pass
                     repo.git.commit("-m", commit_message.format(**vcs_context))
 
                 if tag or kacl_config.git_create_tag:
@@ -618,6 +645,52 @@ def new(output_file):
         click.echo(kacl_changelog_content)
 
 
+@cli.command()
+@click.option(
+    "-f",
+    "--force",
+    required=False,
+    is_flag=True,
+    help="Will overwrite existing files.",
+)
+def init(force):
+    """Initializes a project with all necessary kacl setting."""
+    kacl_changelog = kacl.new()
+    kacl_changelog_content = kacl.dump(kacl_changelog)
+
+    if os.path.exists("CHANGELOG.md") and not force:
+        click.echo(
+            click.style("Error: ", fg="red")
+            + "CHANGELOG.md already exists. Use '--force' to overwrite."
+        )
+        sys.exit(1)
+
+    if os.path.exists(".kacl.yml") and not force:
+        click.echo(
+            click.style("Error: ", fg="red")
+            + ".kacl.yml already exists. Use '--force' to overwrite."
+        )
+        sys.exit(1)
+
+    with open("CHANGELOG.md", "w") as f:
+        f.write(kacl_changelog_content)
+    f.close()
+
+    default_config_file = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), "config", "kacl-default.yml"
+    )
+
+    # copy the default config file
+    if os.path.exists(default_config_file):
+        with open(default_config_file, "r") as df:
+            default_config_content = df.read()
+        df.close()
+
+        with open(".kacl.yml", "w") as cf:
+            cf.write(default_config_content)
+        cf.close()
+
+
 @cli.command("add-comments")
 @click.pass_context
 @click.option(
