@@ -73,14 +73,31 @@ def test_next(tmp_path, snapshot):
         assert result.output == "1.0.1\n"
 
 
+@pytest.mark.parametrize(
+    "stash_dir",
+    [
+        (None, True),
+        ("stash", True),
+        ("stash-no-changes", True),
+        ("stash-invalid", False),
+    ],
+)
 @freeze_time("2023-01-01")
-def test_release_patch(tmp_path, snapshot):
+def test_release_patch(tmp_path, snapshot, stash_dir):
     runner = CliRunner()
     resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
     changelog_file = os.path.join(resources_dir, "CHANGELOG_with_changes.md")
 
+    if stash_dir[0]:
+        stash_dir_local = os.path.join(resources_dir, stash_dir[0])
+
     with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
         shutil.copyfile(changelog_file, os.path.join(project_root_path, "CHANGELOG.md"))
+        if stash_dir[0]:
+            shutil.copytree(
+                stash_dir_local, os.path.join(project_root_path, ".kacl_stash")
+            )
+
         result = runner.invoke(
             cli,
             [
@@ -92,8 +109,12 @@ def test_release_patch(tmp_path, snapshot):
             ],
             catch_exceptions=False,
         )
-        assert result.exit_code == 0, result.output
-        snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
+
+        if not stash_dir[1]:
+            assert result.exit_code == 1, result.output
+        else:
+            assert result.exit_code == 0, result.output
+            snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
 
 
 @freeze_time("2023-01-01")
@@ -311,6 +332,31 @@ def test_add_change_security(tmp_path, snapshot):
         snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
 
 
+@freeze_time("2023-01-01")
+def test_add_change_security_stashed(tmp_path, snapshot):
+    runner = CliRunner()
+    resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
+    changelog_file = os.path.join(resources_dir, "CHANGELOG_with_changes.md")
+
+    with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
+        shutil.copyfile(changelog_file, os.path.join(project_root_path, "CHANGELOG.md"))
+        result = runner.invoke(
+            cli,
+            [
+                "-f",
+                "CHANGELOG.md",
+                "add",
+                "Security",
+                "[STASHED] Important Security Change",
+                "-m",
+                "--stash",
+            ],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 0, result.output
+        snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
+
+
 def test_config(tmp_path, snapshot):
     runner = CliRunner()
     resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
