@@ -45,6 +45,15 @@ class TestKacl(TestCase):
         changelog_reference_lines = changelog_reference.split("\n")
 
         self.assertEqual(len(changelog_dump_lines), len(changelog_reference_lines))
+
+        for i in range(len(changelog_dump_lines)):
+            if changelog_dump_lines[i] != changelog_reference_lines[i]:
+                print(
+                    f"Line {i + 1} differs:\n"
+                    f"Dump: {changelog_dump_lines[i]}\n"
+                    f"Reference: {changelog_reference_lines[i]}"
+                )
+
         self.assertEqual(changelog_dump, changelog_reference)
 
     def test_add_change(self):
@@ -231,8 +240,8 @@ class TestKacl(TestCase):
     def test_release_with_increment(self):
         tests = {
             "major": "2.0.0",
-            "minor": "1.1.0",
-            "patch": "1.0.1",
+            "minor": "1.2.0",
+            "patch": "1.1.2",
         }
         changelog_file = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "data/CHANGELOG.md"
@@ -263,9 +272,9 @@ class TestKacl(TestCase):
     def test_release_with_increment_extension(self):
         tests = {
             "major": "2.0.0",
-            "minor": "1.1.0",
-            "patch": "1.0.1",
-            "post": "1.0.0-post.1",
+            "minor": "1.2.0",
+            "patch": "1.1.2",
+            "post": "1.1.1-post.1",
         }
         changelog_file = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "data/CHANGELOG.md"
@@ -285,9 +294,9 @@ class TestKacl(TestCase):
     def test_release_with_increment_extension_hotfix(self):
         tests = {
             "major": "2.0.0",
-            "minor": "1.1.0",
-            "patch": "1.0.1",
-            "post": "1.0.0-hotfix.1",
+            "minor": "1.2.0",
+            "patch": "1.1.2",
+            "post": "1.1.1-hotfix.1",
         }
         changelog_file = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "data/CHANGELOG.md"
@@ -444,3 +453,36 @@ def test_get_issues(tmp_path):
 
     issues = changelog.get_associated_issues(version=changelog.current_version())
     assert len(issues["jira"]) == 5
+
+
+def test_simple_metadata(tmp_path):
+    changelog_file = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)),
+        "data/CHANGELOG_with_simple_metadata.md",
+    )
+    changelog = kacl.load(changelog_file)
+    assert changelog.is_valid()
+
+    changelog.release(increment="major")
+
+    content = kacl.dump(changelog)
+
+    assert "---\ntitle: CHANGELOG\n---\n" in str(content)
+
+
+def test_complex_metadata(tmp_path):
+    changelog_file = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)),
+        "data/CHANGELOG_with_complex_metadata.md",
+    )
+    changelog = kacl.load(changelog_file)
+    assert changelog.is_valid()
+
+    changelog.release(increment="major")
+
+    content = kacl.dump(changelog)
+
+    assert (
+        "---\nlist:\n- entry1\n- additional: true\n  key: value\ntitle: CHANGELOG\n---\n"
+        in str(content)
+    )
